clear 

set mem 100m

* Cote d'Ivoire 1998

cd "/Users/JRigolini/Desktop/LSMS/"


use ".\Cote d'Ivoire 1998\Cote d'Ivoire 1998.dta", clear

g ccode="CIV"

g cname="Cote d'Ivoire"

g year=1998


rename pond weight

g people0=1
egen peoplw=sum(people0*weight)
drop people0


* Education (3.A.Q10 highest diploma)

g educ=.

* noed=0, prim=1, sec=2, high=3

replace educ=0 if s1q27==1

replace educ=1 if s1q27==2 | s1q27==3

replace educ=2 if s1q27==4

replace educ=3 if s1q27>=5 & s1q27!=.

g sec=educ>=2

g high=educ>=3


* Gender

g sex=(s1q3==2)


* Age

g age=s1q6a

replace age=. if age<0 | age>=99



* Hours Worked per week

g hours=.

replace hours=s1q58

drop if s1q58>150

* Keep if at least 3 hours per week
drop if hours<=3 & hours!=.

* Wages

* Hourly wage

g wage=.

replace wage=s1q67a/hours    	if s1q67b==1  
replace wage=s1q67a/(4*hours)	if s1q67b==2  
replace wage=s1q67a/(12*hours)	if s1q67b==3  
replace wage=s1q67a/(24*hours)	if s1q67b==4  
replace wage=s1q67a/(48*hours)	if s1q67b==5


* Drop agricultural jobs
drop if s1q57b==17 | s1q57b==18 | s1q57b==20


g work=0
replace work=1 if s1q46==1



* Self employed (work or not 05B1Q1, selfemp 05B1Q11)
g sforce=0
replace sforce=1 if work==1 & (s1q57b==14 | s1q57b==15)


* Dependent labor force
g dforce=0
replace dforce=1 if work==1 & (s1q57b>=1 & s1q57b<=13) & s1q57b!=.
replace dforce=1 if work==1 & s1q57b==16


* Unpaid family worker
g uforce=0
replace uforce=1 if work==1 & s1q57b==19



* Social Security

g depssec_f=0
replace depssec_f=1 if dforce==1 & s1q71b==1

g depssec_i=0
replace depssec_i=1 if dforce==1 & s1q71b==2



* Contract:

g depcontr_f=0
replace depcontr_f=1 if dforce==1 & (s1q63==1 | s1q63==2)

g depcontr_i=0
replace depcontr_i=1 if dforce==1 & (s1q63==3 | s1q63==4)



* Public Employee

g public=0
replace public=1 if work==1 & (s1q57b==1 | s1q57b==2 | s1q57b==3 | s1q57b==4)


* Prepare the variables to put them in the reduced-form dataset
* Worker types

egen selfemp=sum(sforce*weight)
egen depemp=sum(dforce*weight)
egen unpaid=sum(uforce*weight)


g sumcf=depcontr_f
egen contrf=sum(sumcf*weight)

g sumci=depcontr_i
egen contri=sum(sumci*weight)


g sumsf=depssec_f
egen sosecf=sum(sumsf*weight)

g sumsi=depssec_i
egen soseci=sum(sumsi*weight)



*Compute aggregate hours and wages

qui reg hours [pweight=weight] if sumcf>0
qui predict clabf

qui reg hours [pweight= weight] if sumci>0
qui predict clabi

qui reg hours [pweight= weight] if sumsf>0
qui predict slabf

qui reg hours [pweight= weight] if sumsi>0
qui predict slabi

qui reg wage [pweight= weight] if sumcf>0
qui predict cwagef

qui reg wage [pweight= weight] if sumci>0
qui predict cwagei

qui reg wage [pweight= weight] if sumsf>0
qui predict swagef

qui reg wage [pweight= weight] if sumsi>0
qui predict swagei



collapse (mean) selfemp depemp unpaid contrf contri sosecf soseci cwagef cwagei swagef swagei clabf clabi slabf slabi, by(ccode cname year)

sort ccode year


save "./reduced.dta", replace


* Merge with the original dataset

use "./results.dta", clear

sort ccode year

merge ccode year using "./reduced.dta"

drop _merge

save, replace














